! This file is part of SusHi.
! 
! It includes the calculation of loop integrals
! as well as logarithms and polylogarithms.
! 
#define integrals 2

#if (integrals==1)

c-{{{ with    QCD-Loop

c-{{{ 2-point-function

      function Integral2(m1,mb2)
      implicit none
      double complex Integral2
      double precision m1, mb2,mh
      integer i
      i=0
      call ffxb0(Integral2, dlog(mb2), 1.d0, m1, mb2, mb2, i)
      end

c-}}}
c-{{{ 3-point-function

      function Integral3(m1,m2,mb2)
      implicit none
      double complex Integral3
      double precision m1,m2,mb2,m(6)
      integer i
      i=0
      m(1)=mb2
      m(2)=mb2
      m(3)=mb2
      m(4)=m1
      m(5)=0.d0
      m(6)=m2
      call ffxc0(Integral3, m, i)
      end

c-}}}
c-{{{ 4-point-function

      function Integral4(m1,m2,m3,mb2)
      implicit none
      double complex Integral4
      double precision m1,m2,m3,mb2,m(13)
      integer i
      i=0
      m(1)=mb2
      m(2)=mb2
      m(3)=mb2
      m(4)=mb2
      m(5)=0.d0
      m(6)=0.d0
      m(7)=0.d0
      m(8)=m1+m2+m3
      m(9)=m1
      m(10)=m3
      m(11)=0.d0
      m(12)=0.d0
      m(13)=0.d0
      call ffxd0(Integral4, m, i)
      end

c-}}}

c-}}}

#elif (integrals>=2)

c-{{{ without QCD-Loop

c-{{{ 2-point-function

      function Integral2(ma,mq2)
      implicit none
      double complex Integral2
      double precision ma,m1,mq2,re,im,Pi,Integral2exp
      parameter (Pi=3.141592653589793238462643D0)
      m1=ma/mq2
      if(m1.eq.0.d0) then
         re=0.d0
         im=0.d0
#if (integrals==3)
      elseif(m1.lt.-2.d0) then
         re = 2.d0-2.d0*dsqrt(1-4/m1)*dlog((dsqrt(-m1)+dsqrt(-m1+4))
     &           /2.d0)
         im = 0.d0
      elseif(m1.lt.2.5d0) then
c     when m1 is close to 0 use an expansion in m1
         re = Integral2exp(m1)
         im = 0.d0
#else
      elseif(m1.lt.-0.022d0) then
         re = 2.d0-2.d0*dsqrt(1-4/m1)*dlog((dsqrt(-m1)+dsqrt(-m1+4))
     &           /2.d0)
         im = 0.d0
      elseif(m1.lt.0.015d0) then
c     when m1 is close to 0 use an expansion in m1
         re = Integral2exp(m1)
         im = 0.d0
#endif
      elseif(m1.lt.4.d0) then
c         re=2D0-2D0*dsqrt(-1+4/m1)*datan(dsqrt(m1/(4-m1)))
         re=2.d0-2.d0*dsqrt(4.d0/m1-1.d0)*dasin(dsqrt(m1)/2.d0)
         im=0.d0
      elseif(m1.gt.4.d0) then
         re=2-2*dsqrt(1-4/m1)*(dlog((dsqrt(m1)+dsqrt(m1-4))/
     &(2.d0)))
         im=2*dsqrt(1-4/m1)*Pi/2.d0
      endif
      Integral2=(1.d0,0.d0)*re+(0.d0,1.d0)*im
      end

c-}}}
c-{{{ 3-point-function

      function Integral3(ma,mb,mq2)
      implicit none
      double complex Integral3,Integral3exp
      double precision tmp,ma,mb,mq2,m1,m2,re,im,Pi
      parameter (Pi=3.141592653589793238462643D0)
      m1=ma/mq2
      m2=mb/mq2

      if(m1.gt.m2) then
         tmp = m2
         m2 = m1
         m1 = tmp
      endif

      tmp = (m2-m1)/m2
#if (integrals==3)
      if((tmp.lt.0.25d0).and.((m2.lt.2.9d0).or.(m2.gt.8.8d0))) then
#else
      if((tmp.lt.0.0085d0).and.((m2.lt.2.0d0).or.(m2.gt.4.0d0))) then
#endif
         Integral3 = Integral3exp(m1,m2)/mq2
         return
      endif

      if(m1.eq.0.d0) then
         re=0.d0
         im=0.d0
      elseif(m1.lt.0.d0) then
         re=(dlog(-((-2D0+m1+dsqrt(m1*(-4+m1)))/2.d0))**2)/4.d0
         im=0.d0
      elseif(m1.lt.4.d0) then
         re=-dasin(dsqrt(m1/4.d0))**2
         im=0.d0
      elseif(m1.gt.4.d0) then
         re=(dlog((-2+m1+dsqrt(m1*(-4+m1)))/(2.d0))**2-Pi**2)/4.d0
         im=-Pi*dlog((-2+m1+dsqrt(m1*(-4+m1)))/2.d0)/(m1-m2)
      endif

      if(m2.eq.0.d0) then
      elseif(m2.lt.0.d0) then
         re=re-(dlog(-((-2+m2+dsqrt(m2*(-4+m2)))/(2.d0)))**2)/4.d0
      elseif(m2.lt.4.d0) then
         re=re+dasin(dsqrt(m2/4.d0))**2
      elseif(m2.gt.4.d0) then
         re=re-(dlog((-2+m2+dsqrt(m2*(-4+m2)))/2.d0)**2-Pi**2)/4.d0
         im=im+Pi*dlog((-2+m2+dsqrt(m2*(-4+m2)))/(2.d0))/(m1-m2)
      endif
      Integral3=((1.d0,0.d0)*2.d0/(m1-m2)*re+(0.d0,1.d0)*im)/mq2
      end

c-}}}
c-{{{ 4-point-function

      function Integral4(ma,mb,mc,mq2)
      implicit none
      double complex Integral4,wrz,p(0:3)
      double precision ma,mb,mc,mq2,m1,m2,m3,x(1:2),pn(0:3),tmp,wrzexp,
     &dli2,arg,zeta2,zeta3,pi
      integer i,k
      double complex cli2,carg
      COMMON/ZETACONST/ZETA2,ZETA3
      parameter (Pi=3.141592653589793238462643D0)

      m1=ma/mq2
      m2=mb/mq2
      m3=mc/mq2
      pn(0)=0.d0
      pn(1)=m1
      pn(2)=m1+m2+m3
      pn(3)=m3

      tmp=1+m1*m3/m2/2.d0
      if(tmp**2.eq.1.d0) then
         Integral4=1/6.d0/mq2**2
         return
      endif

      x(2)=-tmp-dsqrt(tmp**2-1)
      x(1)=1/x(2)

      Integral4=(2.d0,0.d0)*(2*dli2(1+x(2))+dlog(-x(2))**2/2)
      do i=1,3
         wrz=cdsqrt((1.d0,0.d0)*(1-pn(i)/2.d0)**2-1)
         if(pn(i).eq.0.d0) then
            p(i) = 1.d0
         elseif(pn(i).gt.0.d0) then
            p(i)=1/(1-pn(i)/2.d0-wrz)
         else
            p(i)=1-pn(i)/2.d0+wrz
         endif

         do k=1,2
            if(pn(i).le.0.d0) then
               arg = real(p(i)*x(k))
               Integral4=Integral4+(-1)**(i+k)*
     &              (-2*dli2(1+1/arg)-dlog(-arg)**2/2)
            elseif(pn(i).ge.4.d0) then
               arg = real(p(i)*x(k))
               Integral4=Integral4+(-1)**(i+k) * (
     &              dli2(-1/arg)-zeta2-dlog(1+1/arg)*dlog(arg)
     &              -(dlog(arg)-(0.d0,1.d0)*Pi)**2/4.d0
     &              -(0.d0,1.d0)*Pi*dlog(1+arg))*2.d0
            else
               Integral4=Integral4+(-1)**(i+k)*(cli2(1+p(i)*x(k))
     &              +cli2(1+x(k)/p(i)))
            endif
         enddo
      enddo
      Integral4=Integral4/dsqrt(tmp**2-1)/m2/mq2**2/2.d0
      end

c-}}}

c-}}}

#endif

c-{{{ 2-point-function (expansion)

      function Integral2exp(m1)
      implicit none
      double precision Integral2exp,m1
      Integral2exp = 
     -   m1/6.d0 + m1**2/60.d0 + m1**3/420.d0 + m1**4/2520.d0 + 
     -   m1**5/13860.d0

#if (integrals==3)
      Integral2exp = Integral2exp + m1**6/72072.d0 +
     -   m1**7/360360.d0 + m1**8/1.75032d6 + m1**9/8.31402d6 + 
     -   m1**10/3.879876d7 + m1**11/1.78474296d8 + m1**12/8.112468d8 + 
     -   m1**13/3.6506106d9 + m1**14/1.62873396d10 + 
     -   m1**15/7.21296468d10 + 
     -   m1**16/3.1737044592d11 + m1**17/1.3884957009d12 + 
     -   m1**18/6.0440401098d12 + m1**19/2.61908404758d13 + 
     -   m1**20/1.130341536324d14 + m1**21/4.8604686061932d14 + 
     -   m1**22/2.0830579740828d15 + m1**23/8.9003386165356d15 + 
     -   m1**24/3.79231819313256d16 + m1**25/1.611735232081338d17 + 
     -   m1**26/6.833757384024873d17 + m1**27/2.8912050470874465d18 + 
     -   m1**28/1.2207310198813663d19 + m1**29/5.144509298071472d19 + 
     -   m1**30/2.1642418426369642d20 + m1**31/9.089815739075249d20 + 
     -   m1**32/3.811858213160588d21 + m1**33/1.5962156267609963d22 + 
     -   m1**34/6.675083530091439d22 + m1**35/2.7878290037440718d23 + 
     -   m1**36/1.1629229558475271d24 + m1**37/4.845512316031363d24 + 
     -   m1**38/2.016780801807648d25 + m1**39/8.385562281200221d25 + 
     -   m1**40/3.483233562960092d26 + m1**41/1.4455419286284383d27 + 
     -   m1**42/5.993710435776451d27 + m1**43/2.483108609107387d28 + 
     -   m1**44/1.0278914707467787d29 + m1**45/4.251732901725312d29 + 
     -   m1**46/1.757382932713129d30 + m1**47/7.258755591641185d30 + 
     -   m1**48/2.996167201656149d31 + m1**49/1.2359189706831614d32 + 
     -   m1**50/5.095012899550992d32 + m1**51/2.0991453146150086d33 + 
     -   m1**52/8.643539530767682d33 + m1**53/3.5571489607390077d34 + 
     -   m1**54/1.4631291951718937d35 + m1**55/6.01508669126223d35 + 
     -   m1**56/2.4716538040459344d36 + m1**57/1.0151435266617231d37 + 
     -   m1**58/4.167431319979705d37 + m1**59/1.7100838864744308d38 + 
     -   m1**60/7.014242381810378d38 + m1**61/2.875839376542255d39 + 
     -   m1**62/1.1786226953042028d40 + m1**63/4.828551042052701d40 + 
     -   m1**64/1.9774066172215826d41 + m1**65/8.095008339250853d41 + 
     -   m1**66/3.312726489601119d42 + m1**67/1.3552062912004576d43 + 
     -   m1**68/5.542186922222767d43 + m1**69/2.265776418202837d44 + 
     -   m1**70/9.260129709176812d44 + m1**71/3.783424424035097d45 + 
     -   m1**72/1.5453423703805328d46 + m1**73/6.310148012387176d46 + 
     -   m1**74/2.575923435193669d47 + m1**75/1.0512552397682271d48 + 
     -   m1**76/4.2891213782543664d48 + m1**77/1.7495100358669126d49 + 
     -   m1**78/7.134365600807929d49 + m1**79/2.908625975714002d50 + 
     -   m1**80/1.185541220480897d51 + m1**81/4.831080473459655d51 + 
     -   m1**82/1.9682179706687485d52 + m1**83/8.016887831748317d52 + 
     -   m1**84/3.2647085387119653d53 + m1**85/1.3292027621898715d54 + 
     -   m1**86/5.410637126090536d54 + m1**87/2.202003481548474d55 + 
     -   m1**88/8.959876235266204d55 + m1**89/3.645040559346933d56 + 
     -   m1**90/1.4825895308804379d57 + m1**91/6.0291974255804474d57 + 
     -   m1**92/2.4514319202909512d58 + m1**93/9.965603675965389d58 + 
     -   m1**94/4.050535687650448d59 + m1**95/1.646068758172842d60 + 
     -   m1**96/6.688237270049652d60 + m1**97/2.717096390957671d61 + 
     -   m1**98/1.1036453381828066d62 + m1**99/4.482151475477112d62 + 
     -   m1**100/1.8200251445876758d63
#endif
      end

c-}}}
c-{{{ 3-point-function (expansion)

      function Integral3exp(m1,m2)
      implicit none
      double complex Integral3exp,sqrtm1,arc,one
      double precision m1,m2,xxx,yyy,Pi
      parameter (Pi=3.141592653589793238462643D0)

      if(m1.lt.0.d0) then
         write(*,*) 'error in Integral3exp. '
         stop
      endif

      xxx = m2-m1
      sqrtm1 = cdsqrt(((4.d0,0.d0)-m1)*m1)

      if(m1.eq.0.d0) then
         arc = (0.d0,0.d0)
      elseif(m1.lt.0.d0) then
         arc = (0.d0,1.d0)*dlog((dsqrt(4.d0-m1)+dsqrt(-m1))/2.d0)
      elseif(m1.lt.4.d0) then
         arc=dasin(dsqrt(m1)/2.d0)
      elseif(m1.ge.4.d0) then
         arc=-(0.d0,1.d0)*dlog((dsqrt(m1-4.d0)+dsqrt(m1))/2.d0)
     &        +(1.d0,0.d0)*Pi/2.d0
      endif

      Integral3exp = (-2d0*arc)/sqrtm1 - 
     -     ((2*arc*(-2 + m1) + sqrtm1)*xxx)/(2.d0*sqrtm1**3) + 
     -     ((-3*m1**3 + 24*arc*sqrtm1 - 8*m1*(3 + 2*arc*sqrtm1) + 
     -   2*m1**2*(9 + 2*arc*sqrtm1))*xxx**2)/(6.d0*(-4 + m1)**3*m1**3) + 
     -     ((11*m1**4 + 240*arc*sqrtm1 - 4*m1**3*(22 + 3*arc*sqrtm1) - 
     -  24*m1*(10 + 9*arc*sqrtm1) + 4*m1**2*(59 + 18*arc*sqrtm1))*xxx**3
     -     )/(24.d0*(-4 + m1)**4*m1**4) + 
     -     ((-25d0*m1**5 + 1680d0*arc*sqrtm1 -
     -     240d0*m1*(7d0 + 8d0*arc*sqrtm1) + 
     -     m1**4*(250d0 + 24d0*arc*sqrtm1) -
     -     2d0*m1**3*(505d0 + 96d0*arc*sqrtm1) + 
     -   4d0*m1**2*(515d0 +
     -     216d0*arc*sqrtm1))*xxx**4)/(60.d0*(-4d0 + m1)**5*m1**5)
     -     + ((137d0*m1**6 + 30240d0*arc*sqrtm1 - 
     -     12d0*m1**5*(137d0 + 10d0*arc*sqrtm1) -
     -     1680d0*m1*(18d0 + 25d0*arc*sqrtm1) + 
     -     120d0*m1**2*(371d0 + 200d0*arc*sqrtm1) + 
     -     6d0*m1**4*(1481d0 + 200d0*arc*sqrtm1) - 
     -     16d0*m1**3*(1703d0 + 450d0*arc*sqrtm1))*xxx**5)/
     -     (360.d0*(-4d0 + m1)**6*m1**6)

#if (integrals==3)
      Integral3exp = Integral3exp + 
     -   ((-49*m1**7 + 36960d0*arc*sqrtm1 -
     -     3360d0*m1*(11d0 + 18d0*arc*sqrtm1) + 
     -    m1**6*(686d0 + 40d0*arc*sqrtm1) +
     -     80d0*m1**4*(238d0 + 45d0*arc*sqrtm1) - 
     -     8d0*m1**5*(581d0 + 60d0*arc*sqrtm1) + 
     -     280d0*m1**2*(227d0 + 150d0*arc*sqrtm1) - 
     -     4d0*m1**3*(11683d0 + 4000d0*arc*sqrtm1))*xxx**6)/
     -     (140.d0*(-4d0 + m1)**7*m1**7) + 
     - ((363d0*m1**8 + 960960d0*arc*sqrtm1 -
     -     8d0*m1**7*(726d0 + 35d0*arc*sqrtm1) - 
     -     36960d0*m1*(26d0 + 49d0*arc*sqrtm1) - 
     -     144d0*m1**5*(1686d0 + 245d0*arc*sqrtm1) + 
     -     8d0*m1**6*(5917d0 + 490d0*arc*sqrtm1) + 
     -     560d0*m1**2*(3377d0 + 2646d0*arc*sqrtm1) - 
     -     112d0*m1**3*(14506d0 + 6125d0*arc*sqrtm1) + 
     -     4d0*m1**4*(198883d0 + 49000d0*arc*sqrtm1))*xxx**7)/
     -     (1120.d0*(-4d0 + m1)**8*m1**8) + 
     -     ((-761d0*m1**9 + 7207200d0*arc*sqrtm1 -
     -     480480d0*m1*(15d0 + 32d0*arc*sqrtm1) + 
     -     64680d0*m1**2*(247d0 + 224d0*arc*sqrtm1) + 
     -     2d0*m1**8*(6849d0 + 280d0*arc*sqrtm1) + 
     -     84d0*m1**6*(9577d0 + 1120d0*arc*sqrtm1) - 
     -     2d0*m1**7*(65259d0 + 4480d0*arc*sqrtm1) - 
     -     140d0*m1**3*(112211d0 + 56448d0*arc*sqrtm1) - 
     -     2d0*m1**5*(1649349d0 + 313600d0*arc*sqrtm1) + 
     -     4d0*m1**4*(2247633d0 + 686000d0*arc*sqrtm1))*xxx**8)/
     -     (2520.d0*(-4d0 + m1)**9*m1**9) + 
     -     ((7129d0*m1**10 + 245044800d0*arc*sqrtm1 - 
     -     7207200d0*m1*(34d0 + 81d0*arc*sqrtm1) - 
     -     20d0*m1**9*(7129d0 + 252d0*arc*sqrtm1) - 
     -     258720d0*m1**3*(2587d0 + 1512d0*arc*sqrtm1) + 
     -     240240d0*m1**2*(2515d0 + 2592d0*arc*sqrtm1) - 
     -     160d0*m1**7*(69997d0 + 6804d0*arc*sqrtm1) + 
     -     10d0*m1**8*(155545d0 + 9072d0*arc*sqrtm1) + 
     -     10d0*m1**6*(5516309d0 + 846720d0*arc*sqrtm1) + 
     -     60d0*m1**4*(7308389d0 + 2667168d0*arc*sqrtm1) - 
     -     8d0*m1**5*(23510747d0 +
     -     5556600d0*arc*sqrtm1))*xxx**9)/
     -     (25200.d0*(-4d0 + m1)**10*m1**10) + 
     -     ((-11d0*m1*(84651840d0 - 229822320d0*m1 +
     -     283214568d0*m1**2 - 
     -     209054976d0*m1**3 + 102667504d0*m1**4 -
     -     35207452d0*m1**5 + 
     -     8598530d0*m1**6 - 1494984d0*m1**7 + 181468d0*m1**8 -
     -     14762d0*m1**9 + 
     -     671d0*m1**10) + 5040d0*arc*
     -     (184756d0 - 486200d0*m1 + 579150d0*m1**2 -
     -     411840d0*m1**3 + 
     -     194040d0*m1**4 - 63504d0*m1**5 + 14700d0*m1**6 -
     -     2400d0*m1**7 + 
     -     270d0*m1**8 - 20d0*m1**9 + m1**10)*sqrtm1)*xxx**10)/
     -     (27720.d0*(-4 + m1)**11*m1**11) + 
     -     ((83711d0*m1**12 + 39109150080d0*arc*sqrtm1 - 
     -     931170240d0*m1*(42d0 + 121d0*arc*sqrtm1) - 
     -     24d0*m1**11*(83711d0 + 2310d0*arc*sqrtm1) + 
     -     24504480d0*m1**2*(4731d0 + 6050d0*arc*sqrtm1) - 
     -     560d0*m1**9*(455297d0 + 32670d0*arc*sqrtm1) + 
     -     12d0*m1**10*(2290121d0 + 101640d0*arc*sqrtm1) + 
     -     360360d0*m1**4*(358507d0 + 174240d0*arc*sqrtm1) - 
     -     96096d0*m1**3*(1637066d0 + 1225125d0*arc*sqrtm1) - 
     -     4224d0*m1**5*(16924921d0 + 5602905d0*arc*sqrtm1) - 
     -     96d0*m1**7*(83521447d0 + 13340250d0*arc*sqrtm1) + 
     -     6d0*m1**8*(279555223d0 + 30492000d0*arc*sqrtm1) + 
     -     32d0*m1**6*(877298869d0 +
     -     201704580d0*arc*sqrtm1))*xxx**11)/
     -     (332640.d0*(-4 + m1)**12*m1**12) + 
     -     ((-13*m1*(11532185280d0 - 37061769360d0*m1 +
     -     54914571096d0*m1**2 - 
     -     49662444216d0*m1**3 + 30577044652d0*m1**4 -
     -     13530896768d0*m1**5 + 
     -     4425818944d0*m1**6 - 1082903232d0*m1**7 +
     -     198097008d0*m1**8 - 
     -     26746236d0*m1**9 + 2592074d0*m1**10 -
     -     172042d0*m1**11 + 6617d0*m1**12
     -     ) + 55440d0*arc*(2704156d0 - 8465184d0*m1 +
     -     12193896d0*m1**2 - 
     -     10696400d0*m1**3 + 6370650*m1**4 - 2718144d0*m1**5 + 
     -     853776d0*m1**6 - 199584d0*m1**7 + 34650d0*m1**8 -
     -     4400d0*m1**9 + 
     -     396d0*m1**10 - 24d0*m1**11 + m1**12)*sqrtm1)*xxx**12)/
     -     (360360.d0*(-4d0 + m1)**13*m1**13) + 
     - ((m1*(-7495920432000d0 + 25960871096160d0*m1 -
     -     41705563099200d0*m1**2 + 
     -     41185512279912d0*m1**3 - 27926391501008d0*m1**4 + 
     -     13750761838268d0*m1**5 - 5068902304768d0*m1**6 + 
     -     1420528664128d0*m1**7 - 303977994432d0*m1**8 + 
     -     49400221584d0*m1**9 - 5998669264d0*m1**10 +
     -     528038854d0*m1**11 - 
     -     32087804d0*m1**12 + 1145993d0*m1**13) - 
     -     720720d0*arc*(-10400600d0 + 35154028d0*m1 -
     -     55023696d0*m1**2 + 
     -     52840216d0*m1**3 - 34763300d0*m1**4 +
     -     16563690d0*m1**5 - 
     -     5889312d0*m1**6 + 1585584d0*m1**7 - 324324d0*m1**8 +
     -     50050d0*m1**9 - 
     -     5720d0*m1**10 + 468d0*m1**11 - 26d0*m1**12 +
     -     m1**13d0)*sqrtm1)*
     -     xxx**13)/(5.04504d6*(-4 + m1)**14*m1**14) + 
     -     ((m1*(-28912835952000d0 + 107352289044000d0*m1 -
     -     185857777625520d0*m1**2 + 
     -     199003850622720d0*m1**3 - 147353792867424d0*m1**4 + 
     -     79909589389240d0*m1**5 - 32778857585220d0*m1**6 + 
     -     10353388072320d0*m1**7 - 2537786272000d0*m1**8 + 
     -     482500207728d0*m1**9 - 70533505320d0*m1**10 + 
     -     7781252960d0*m1**11 - 627364200d0*m1**12 +
     -     35151990d0*m1**13 - 
     -     1171733d0*m1**14) + 
     -     720720d0*arc*(40116600d0 - 145608400d0*m1 +
     -     246078196d0*m1**2 - 
     -     256777248d0*m1**3 + 184940756d0*m1**4 - 97337240d0*m1**5 + 
     -     38648610d0*m1**6 - 11778624d0*m1**7 + 2774772d0*m1**8 - 
     -     504504d0*m1**9 + 70070d0*m1**10 - 7280d0*m1**11 +
     -     546d0*m1**12 - 
     -     28d0*m1**13 + m1**14)*sqrtm1)*xxx**14)/
     -     (5.4054d6*(-4 + m1)**15*m1**15) + 
     -     ((m1*(-111796299014400d0 + 443008897531200d0*m1 - 
     -     822281054474880d0*m1**2 + 948875677223760d0*m1**3 - 
     -     761824338887040d0*m1**4 + 451169405450400d0*m1**5 - 
     -     203835979218240d0*m1**6 + 71647612224212d0*m1**7 - 
     -     19795041361024d0*m1**8 + 4311376330016d0*m1**9 - 
     -     737423000128d0*m1**10 + 97950383000d0*m1**11 - 
     -     9899460928d0*m1**12 + 736194416d0*m1**13 -
     -     38264224d0*m1**14 + 
     -     1195757d0*m1**15) - 
     -     720720d0*arc*(-155117520d0 + 601749000d0*m1 -
     -     1092063000d0*m1**2 + 
     -     1230390980d0*m1**3 - 962914680d0*m1**4 +
     -     554822268d0*m1**5 - 
     -     243343100d0*m1**6 + 82818450d0*m1**7 - 22084920d0*m1**8 + 
     -     4624620d0*m1**9 - 756756d0*m1**10 + 95550d0*m1**11 -
     -     9100d0*m1**12 + 
     -     630d0*m1**13 - 30d0*m1**14 + m1**15)*sqrtm1)*xxx**15)/
     -     (5.76576d6*(-4 + m1)**16*m1**16) + 
     -     ((-17*m1*(50965959844800d0 - 214687255582800d0*m1 + 
     -     425293171463160d0*m1**2 - 526170982966200d0*m1**3 + 
     -     455295274288140d0*m1**4 - 292373325823800d0*m1**5 + 
     -     144258823706820d0*m1**6 - 55850676600844d0*m1**7 + 
     -     17172664670710d0*m1**8 - 4216056009176d0*m1**9 + 
     -     826147688932d0*m1**10 - 128408259668d0*m1**11 + 
     -     15627578626d0*m1**12 - 1457108060d0*m1**13 +
     -     100550194d0*m1**14 - 
     -     4873118d0*m1**15 + 143327d0*m1**16) + 
     -     1441440d0*arc*(601080390d0 - 2481880320d0*m1 +
     -     4813992000d0*m1**2 - 
     -     5824336000d0*m1**3 + 4921563920d0*m1**4 -
     -     3081326976d0*m1**5 + 
     -     1479526048d0*m1**6 - 556212800d0*m1**7 +
     -     165636900d0*m1**8 - 
     -     39262080d0*m1**9 + 7399392d0*m1**10 - 1100736d0*m1**11 + 
     -     127400d0*m1**12 - 11200d0*m1**13 + 720d0*m1**14 -
     -     32d0*m1**15 + 
     -     m1**16)*sqrtm1)*xxx**16)/(1.225224d7*(-4 + m1)**17*m1**17) + 
     -     ((m1*(-57183806945865600d0 + 255161077962991200d0*m1 - 
     -     537335868311161920d0*m1**2 + 709525052385126120d0*m1**3 - 
     -     658254138767493840d0*m1**4 + 455585983401248700d0*m1**5 - 
     -     243751773244167360d0*m1**6 + 103065232931325468d0*m1**7 - 
     -     34906313633927288d0*m1**8 + 9537790837177926d0*m1**9 - 
     -     2106847634334624d0*m1**10 + 375188734261452d0*m1**11 - 
     -     53435991864024d0*m1**12 + 6000403597722d0*m1**13 - 
     -     519239304384d0*m1**14 + 33420255246d0*m1**15 - 
     -     1517120028d0*m1**16 + 42142223d0*m1**17) - 
     -     24504480d0*arc*(-2333606220d0 + 10218366630d0*m1 - 
     -     21095982720d0*m1**2 + 27279288000d0*m1**3 -
     -     24753428000d0*m1**4 + 
     -     16733317328d0*m1**5 - 8730426432d0*m1**6 +
     -     3593134688d0*m1**7 - 
     -     1181952200d0*m1**8 + 312869700d0*m1**9 - 66745536d0*m1**10 + 
     -     11435424d0*m1**11 - 1559376d0*m1**12 + 166600d0*m1**13 - 
     -     13600d0*m1**14 + 816d0*m1**15 - 34d0*m1**16 +
     -     m1**17)*sqrtm1)*
     -     xxx**17)/(2.2054032d8*(-4 + m1)**18*m1**18) + 
     -     ((-19*m1*(3901429323792000d0 - 18383163409010400d0*m1 + 
     -     41008497858728400d0*m1**2 - 57564219459626880d0*m1**3 + 
     -     56999404521007520d0*m1**4 - 42297634430142520d0*m1**5 + 
     -     24391371602795780d0*m1**6 - 11183697675906320d0*m1**7 + 
     -     4136846013196792d0*m1**8 - 1245121594094708d0*m1**9 + 
     -     306119668114158d0*m1**10 - 61456082888928d0*m1**11 + 
     -     10029027694848d0*m1**12 - 1318036074244d0*m1**13 + 
     -     137375726942d0*m1**14 - 11089677592d0*m1**15 + 
     -     668750212d0*m1**16 - 28548602d0*m1**17 + 751279d0*m1**18) + 
     -    8168160d0*arc*(9075135300d0 - 42004911960d0*m1 +
     -     91965299670d0*m1**2 - 
     -     126575896320d0*m1**3 + 122756796000d0*m1**4 - 
     -     89112340800d0*m1**5 + 50199951984d0*m1**6 -
     -     22449667968d0*m1**7 + 
     -     8084553048d0*m1**8 - 2363904400d0*m1**9 +
     -     563165460d0*m1**10 - 
     -     109219968d0*m1**11 + 17153136d0*m1**12 - 2159136d0*m1**13 + 
     -     214200d0*m1**14 - 16320d0*m1**15 + 918d0*m1**16 -
     -     36d0*m1**17 + 
     -     m1**18)*sqrtm1)*xxx**18)/(7.759752d7*(-4 + m1)**19*m1**19)

      Integral3exp = Integral3exp +
     -     ((m1*(-5485409629251552000d0 +
     -     27217021200993624000d0*m1 - 
     -     64114343153119459200d0*m1**2 +
     -     95337239247675625200d0*m1**3 - 
     -     100356192569544271360d0*m1**4 +
     -     79485805742318060800d0*m1**5 - 
     -     49145917043686126400d0*m1**6 +
     -     24287854710822210420d0*m1**7 - 
     -     9742468730900017120d0*m1**8 +
     -     3202700783772296504d0*m1**9 - 
     -     867379872121251920d0*m1**10 +
     -     193818290978987310d0*m1**11 - 
     -     35658823781590080d0*m1**12 + 5369968979559920d0*m1**13 - 
     -     655103994744512d0*m1**14 + 63703057843030d0*m1**15 - 
     -     4818784193040d0*m1**16 + 273338321300d0*m1**17 - 
     -     11011831960d0*m1**18 + 275295799d0*m1**19) - 
     -     155195040d0*arc*(-35345263800d0 + 172427570700d0*m1 - 
     -     399046663620d0*m1**2 + 582446897910d0*m1**3 - 
     -     601235507520d0*m1**4 + 466475824800d0*m1**5 - 
     -     282189079200d0*m1**6 + 136257012528d0*m1**7 - 
     -     53317961424d0*m1**8 + 17067389768d0*m1**9 -
     -     4491418360d0*m1**10 + 
     -     972740340d0*m1**11 - 172931616d0*m1**12 + 25069968d0*m1**13 - 
     -     2930256d0*m1**14 + 271320d0*m1**15 - 19380d0*m1**16 + 
     -     1026d0*m1**17 - 38d0*m1**18 + m1**19)*sqrtm1)*xxx**19)/
     -     (1.5519504d9*(-4 + m1)**20*m1**20) + 
     -     ((m1*(-4278619510816210560d0 + 22298190142907558880d0*m1 - 
     -     55312622177605704912d0*m1**2 + 86855647792158829584d0*m1**3 - 
     -     96853261391764613736d0*m1**4 + 81551157144010922368d0*m1**5 - 
     -     53818911395229414720d0*m1**6 + 28518222862972387776d0*m1**7 - 
     -     12330025474725254912d0*m1**8 + 4395594520622311608d0*m1**9 - 
     -     1300251777324780084d0*m1**10 + 320066534808141940d0*m1**11 - 
     -     65545177094088930d0*m1**12 + 11128680315166800d0*m1**13 - 
     -     1555761631009880d0*m1**14 + 177084444291720d0*m1**15 - 
     -     16137679174260d0*m1**16 + 1148410431700d0*m1**17 - 
     -     61489002750d0*m1**18 + 2345075670d0*m1**19 -
     -     55835135d0*m1**20) + 
     -     31039008d0*arc*(137846528820d0 - 706905276000d0*m1 + 
     -     1724275707000d0*m1**2 - 2660311090800d0*m1**3 + 
     -     2912234489550d0*m1**4 - 2404942030080d0*m1**5 + 
     -     1554919416000d0*m1**6 - 806254512000d0*m1**7 + 
     -     340642531320d0*m1**8 - 118484358720d0*m1**9 + 
     -     34134779536d0*m1**10 - 8166215200d0*m1**11 +
     -     1621233900d0*m1**12 - 
     -     266048640d0*m1**13 + 35814240d0*m1**14 - 3907008d0*m1**15 + 
     -     339150d0*m1**16 - 22800d0*m1**17 +
     -     1140d0*m1**18 - 40d0*m1**19 + m1**20
     -     )*sqrtm1)*xxx**20)/(3.25909584d8*(-4 + m1)**21*m1**21) + 
     -     ((m1*(-16706990470806155520d0 + 91243258933040934720d0*m1 - 
     -     237735563651903501184d0*m1**2 +
     -     393108716808808194480d0*m1**3 - 
     -     462914085382282023776d0*m1**4 +
     -     412910979274658759752d0*m1**5 - 
     -     289692881674190179328d0*m1**6 +
     -     163847226014280549312d0*m1**7 - 
     -     75958089655306615680d0*m1**8 +
     -     29187565553194089888d0*m1**9 - 
     -     9363187315342377632d0*m1**10 +
     -     2517471315978781228d0*m1**11 - 
     -     567943824033347960d0*m1**12 +
     -     107337604870473010d0*m1**13 - 
     -     16918740374539520d0*m1**14 + 2206933879484488d0*m1**15 - 
     -     235432714465872d0*m1**16 + 20185796337300d0*m1**17 - 
     -     1356113143440d0*m1**18 + 68752510530d0*m1**19 - 
     -     2489262996d0*m1**20 + 56574159d0*m1**21) - 
     -     31039008d0*arc*(-538257874440d0 + 2894777105220d0*m1 - 
     -     7422505398000d0*m1**2 + 12069929949000d0*m1**3 - 
     -     13966633226700d0*m1**4 + 12231384856110d0*m1**5 - 
     -     8417297105280d0*m1**6 + 4664758248000d0*m1**7 - 
     -     2116418094000d0*m1**8 + 794832573080d0*m1**9 - 
     -     248817153312d0*m1**10 + 65166397296d0*m1**11 - 
     -     14290876600d0*m1**12 + 2618916300d0*m1**13 -
     -     399072960d0*m1**14 + 
     -     50139936d0*m1**15 - 5127948d0*m1**16 + 418950d0*m1**17 - 
     -     26600d0*m1**18 + 1260d0*m1**19 -
     -     42d0*m1**20 + m1**21)*sqrtm1)*
     -     xxx**21)/(3.41429088d8*(-4 + m1)**22*m1**22)

      Integral3exp = Integral3exp +
     -     ((-23*m1*(2839528024682469120.d0 -
     -     16217226916161311040.d0*m1 + 
     -     44280275941606889184.d0*m1**2 -
     -     76908017048753789184.d0*m1**3 + 
     -     95369262224078942528.d0*m1**4 -
     -     89834006578093314992.d0*m1**5 + 
     -     66767873998946062696.d0*m1**6 -
     -     40146823106709100288.d0*m1**7 + 
     -     19865807448974178432.d0*m1**8 -
     -     8185224649710542784.d0*m1**9 + 
     -     2830314136769339552.d0*m1**10 -
     -     825278564240212160.d0*m1**11 + 
     -     203366717798915440.d0*m1**12 -
     -     42342739813083380.d0*m1**13 + 
     -     7429388964804070.d0*m1**14 -
     -     1092719142524768.d0*m1**15 + 
     -     133595420336336.d0*m1**16 - 13409578708056.d0*m1**17 + 
     -     1085488604580.d0*m1**18 - 69059062800.d0*m1**19 + 
     -     3324464736.d0*m1**20 - 114559182.d0*m1**21 +
     -     2490417.d0*m1**22) + 
     -     31039008.d0*arc*(2104098963720.d0 - 11841673237680.d0*m1 + 
     -     31842548157420.d0*m1**2 - 54431706252000.d0*m1**3 + 
     -     66384614719500.d0*m1**4 - 61453186197480.d0*m1**5 + 
     -     44848411139070.d0*m1**6 - 26454362330880.d0*m1**7 + 
     -     12828085182000.d0*m1**8 - 5173466452000.d0*m1**9 + 
     -     1748631660776.d0*m1**10 - 497634306624.d0*m1**11 + 
     -     119471728376.d0*m1**12 - 24184560400.d0*m1**13 + 
     -     4115439900.d0*m1**14 - 585307008.d0*m1**15 +
     -     68942412.d0*m1**16 - 
     -     6636168.d0*m1**17 + 512050.d0*m1**18 - 30800.d0*m1**19 + 
     -     1386.d0*m1**20 - 44.d0*m1**21 + m1**22)*sqrtm1)*xxx**22)/
     -     (3.56948592d8*(-4 + m1)**23*m1**23)

      Integral3exp = Integral3exp +
     -     ((m1*(-5877823011092711078400d0 +
     -     35038356060569327706240d0*m1 - 
     -     100048040480887879860480d0*m1**2 + 
     -     182101599592589065248288d0*m1**3 - 
     -     237190420969786584698112d0*m1**4 + 
     -     235278748735140269179072d0*m1**5 - 
     -     184667419931564755416192d0*m1**6 + 
     -     117631658288425783991112d0*m1**7 - 
     -     61882384048731595867648d0*m1**8 + 
     -     27215574872607943975296d0*m1**9 - 
     -     10090874034465119198976d0*m1**10 + 
     -     3171614833613106398368d0*m1**11 - 
     -     847604823088709490432d0*m1**12 + 
     -     192770598868492269504d0*m1**13 -
     -     37263097506350443200d0*m1**14 + 
     -     6101069743488598230d0*m1**15 -
     -     841084362974846016d0*m1**16 + 
     -     96758463752128208d0*m1**17 -
     -     9170005578386976d0*m1**18 + 
     -     703007489692980d0*m1**19 - 42473061919200d0*m1**20 + 
     -     1946348133192d0*m1**21 - 63981604656d0*m1**22 +
     -     1332950097d0*m1**23
     -     ) - 713897184d0*arc*
     -     (-8233430727600d0 + 48394276165560d0*m1 -
     -     136179242233320d0*m1**2 + 
     -     244126202540220d0*m1**3 - 312982310949000d0*m1**4 + 
     -     305369227709700d0*m1**5 - 235570547090340d0*m1**6 + 
     -     147359065171230d0*m1**7 - 76056291701280d0*m1**8 + 
     -     32782884354000d0*m1**9 - 11898972839600d0*m1**10 + 
     -     3656229836168d0*m1**11 - 953799087696d0*m1**12 + 
     -     211373057896d0*m1**13 - 39731777800d0*m1**14 + 
     -     6310341180d0*m1**15 - 841378824d0*m1**16 + 
     -     93275028d0*m1**17 - 
     -     8479548d0*m1**18 + 619850d0*m1**19 - 35420d0*m1**20 + 
     -     1518d0*m1**21 - 46d0*m1**22 + m1**23)*sqrtm1)*xxx**23)/
     -     (8.566766208d9*(-4 + m1)**24*m1**24)

      Integral3exp = Integral3exp +
     -    ((m1*(-23021473460113118390400d0 +
     -     142986208387901159080800d0*m1 - 
     -     426146250125757034233360d0*m1**2 + 
     -     811144199787085155522960d0*m1**3 - 
     -     1107206552537556024815976d0*m1**4 + 
     -     1153624211222062227320400d0*m1**5 - 
     -     953518309103986071365400d0*m1**6 + 
     -     641428140253299952372040d0*m1**7 - 
     -     357475072093095275895940d0*m1**8 + 
     -     167143357277063616680192d0*m1**9 - 
     -     66150349407021376931200d0*m1**10 + 
     -     22294479885757258851200d0*m1**11 - 
     -     6422485886818312212160d0*m1**12 + 
     -     1584135302744139224960d0*m1**13 - 
     -     334493749822230509632d0*m1**14 +
     -     60337855051730379200d0*m1**15 - 
     -     9259932387518046400d0*m1**16 +
     -     1201221872020423400d0*m1**17 - 
     -     130481477705105500d0*m1**18 + 11712085944446300d0*m1**19 - 
     -     852738063154150d0*m1**20 + 49048081994300d0*m1**21 - 
     -     2144521016050d0*m1**22 + 67391147750d0*m1**23 -
     -     1347822955d0*m1**24
     -     ) + 713897184d0*arc*
     -    (32247603683100d0 - 197602337462400d0*m1 +
     -     580731313986720d0*m1**2 - 
     -     1089433937866560d0*m1**3 + 1464757215241320d0*m1**4 - 
     -     1502315092555200d0*m1**5 + 1221476910838800d0*m1**6 - 
     -     807670447166880d0*m1**7 + 442077195513690d0*m1**8 - 
     -     202816777870080d0*m1**9 + 78678922449600d0*m1**10 - 
     -     25961395286400d0*m1**11 + 7312459672336d0*m1**12 - 
     -     1760859854208d0*m1**13 + 362353813536d0*m1**14 - 
     -     63570844480d0*m1**15 + 9465511770d0*m1**16 -
     -     1187828928d0*m1**17 + 
     -     124366704d0*m1**18 - 10711008d0*m1**19 + 743820d0*m1**20 - 
     -     40480d0*m1**21 + 1656d0*m1**22 -
     -     48d0*m1**23 +m1**24)*sqrtm1)*
     -     xxx**24)/(8.9237148d9*(-4 + m1)**25*m1**25)

      Integral3exp = Integral3exp +
     -     ((m1*(-2256104399091085602259200d0 + 
     -     14576429612494956127521600d0*m1 - 
     -     45263906789250465624147840d0*m1**2 + 
     -     89927765403677539587128880d0*m1**3 - 
     -     128369401405817803672103520d0*m1**4 + 
     -     140167574970780693796404360d0*m1**5 - 
     -     121693050660223340258563200d0*m1**6 + 
     -     86207592607845129849112360d0*m1**7 - 
     -     50737878663488605310896720d0*m1**8 + 
     -     25132458878113450934478980d0*m1**9 - 
     -     10574886343524291234135040d0*m1**10 + 
     -     3804328445497016738537600d0*m1**11 - 
     -     1175177130456279205481728d0*m1**12 + 
     -     312458249099792277799616d0*m1**13 - 
     -     71554524071537126324224d0*m1**14 + 
     -     14099551802905415118272d0*m1**15 - 
     -     2384011235984241061120d0*m1**16 + 
     -     344286657757074191744d0*m1**17 - 
     -     42172219312500473248d0*m1**18 + 
     -     4338853164529680212d0*m1**19 -
     -     369891688575161896d0*m1**20 + 
     -     25641283433120030d0*m1**21 - 1407316170446368d0*m1**22 + 
     -     58831273022366d0*m1**23 - 1770731168284d0*m1**24 + 
     -     34052522467d0*m1**25) - 
     -     17847429600d0*arc*(-126410606437752d0 +
     -     806190092077500d0*m1- 
     -     2470029218280000d0*m1**2 + 4839427616556000d0*m1**3 - 
     -     6808962111666000d0*m1**4 + 7323786076206600d0*m1**5 - 
     -     6259646218980000d0*m1**6 + 4362417538710000d0*m1**7 - 
     -     2523970147396500d0*m1**8 + 1227992209760250d0*m1**9 - 
     -     507041944675200d0*m1**10 + 178815732840000d0*m1**11 - 
     -     54086240180000d0*m1**12 + 14062422446800d0*m1**13 - 
     -     3144392596800d0*m1**14 + 603923022560d0*m1**15 - 
     -     99329444500d0*m1**16 + 13919870250d0*m1**17 - 
     -     1649762400d0*m1**18 + 163640400d0*m1**19 -
     -     13388760d0*m1**20+ 
     -     885500d0*m1**21 - 46000d0*m1**22 + 1800d0*m1**23 - 
     -     50d0*m1**24 + m1**25)*sqrtm1)*xxx**25)/
     -     (2.320165848d11*(-4 + m1)**26*m1**26)

      Integral3exp = Integral3exp +
     -     ((m1*(-8850871104126566593478400d0 +
     -     59396286968378772874862400d0*m1 - 
     -     191863940802248717671949280d0*m1**2 + 
     -     397167665841155845181145600d0*m1**3 - 
     -     591761272045563825319033920d0*m1**4 + 
     -     675728869711750787318028240d0*m1**5 - 
     -     614814341056210307929964760d0*m1**6 + 
     -     457488812496070751050285920d0*m1**7 - 
     -     283551213571257622633950800d0*m1**8 + 
     -     148329321135170777161546680d0*m1**9 - 
     -     66119749868170004400183060d0*m1**10 + 
     -     25289239736335244519946240d0*m1**11 - 
     -     8338794228196416342867456d0*m1**12 + 
     -     2377481169838653250104960d0*m1**13 - 
     -     586905393202476917609664d0*m1**14 + 
     -     125427541260541634419968d0*m1**15 - 
     -     23167040644244182413312d0*m1**16 + 
     -     3686185451934279179808d0*m1**17 - 
     -     502679749739845944240d0*m1**18 +
     -     58322263209385505472d0*m1**19 -
     -     5699204815341289104d0*m1**20 +
     -     462614929013353356d0*m1**21 - 
     -     30602700385290666d0*m1**22 +
     -     1606060029018600d0*m1**23 - 
     -     64315615342284d0*m1**24 +
     -     1857370082418d0*m1**25 - 
     -     34395742267d0*m1**26) + 
     -     17847429600d0*arc*(495918532948104d0 -
     -     3286675767381552d0*m1 + 
     -     10480471197007500d0*m1**2 - 21406919891760000d0*m1**3 + 
     -     31456279507614000d0*m1**4 - 35406602980663200d0*m1**5 + 
     -     31736406330228600d0*m1**6 - 23250114527640000d0*m1**7 + 
     -     14177857000807500d0*m1**8 - 7291469314701000d0*m1**9 + 
     -     3192779745376650d0*m1**10 - 1198462778323200d0*m1**11 + 
     -     387434087820000d0*m1**12 - 108172480360000d0*m1**13 + 
     -     26115927401200d0*m1**14 - 5450280501120d0*m1**15 + 
     -     981374911660d0*m1**16 - 151915621000d0*m1**17 + 
     -     20106479250d0*m1**18 - 2257569600d0*m1**19 +
     -     212732520d0*m1**20 - 
     -     16576560d0*m1**21 + 1046500d0*m1**22 - 52000d0*m1**23 + 
     -     1950d0*m1**24 - 52d0*m1**25 + m1**26)*sqrtm1)*xxx**26)/
     -     (2.409402996d11*(-4 + m1)**27*m1**27)

      Integral3exp = Integral3exp +
     -     ((m1*(-312730779012472019636236800d0 + 
     -     2176822576553795017184937600d0*m1 - 
     -     7303657846762198457557781760d0*m1**2 + 
     -     15727375988558261447195936160d0*m1**3 - 
     -     24415743982636016351709688320d0*m1**4 + 
     -     29100689320386599528818558080d0*m1**5 - 
     -     27689639337722876439377005440d0*m1**6 + 
     -     21592846660886373502007117880d0*m1**7 - 
     -     14057908917487785817944536640d0*m1**8 + 
     -     7744328523599322683437720080d0*m1**9 - 
     -     3645728979205189673570749920d0*m1**10 + 
     -     1477258014835690046559168660d0*m1**11 - 
     -     517881563650422259668559872d0*m1**12 + 
     -     157612712315643946037007872d0*m1**13 - 
     -     41722736794223173096167424d0*m1**14 + 
     -     9611906744438076507106496d0*m1**15 - 
     -     1925531660578820501113088d0*m1**16 + 
     -     334687765544024465844544d0*m1**17 - 
     -     50287259294204827696256d0*m1**18 + 
     -     6495607575407573473872d0*m1**19 - 
     -     715825743095836462848d0*m1**20 +
     -     66605373266305085184d0*m1**21 - 
     -     5159533366183282016d0*m1**22 +
     -     326383744169611282d0*m1**23 - 
     -     16409987979445424d0*m1**24 + 630613233931436d0*m1**25 - 
     -     17502030112168d0*m1**26 + 312536252003d0*m1**27) - 
     -     160626866400d0*arc*(-1946939425648112d0 +
     -     13389800389598808d0*m1 - 
     -     44370122859650952d0*m1**2 + 94324240773067500d0*m1**3 - 
     -     144496709269380000d0*m1**4 + 169863909341115600d0*m1**5 - 
     -     159329713412984400d0*m1**6 + 122411852988024600d0*m1**7 - 
     -     78469136530785000d0*m1**8 + 42533571002422500d0*m1**9 - 
     -     19686967149692700d0*m1**10 + 7836823011379050d0*m1**11 - 
     -     2696541251227200d0*m1**12 + 804670797780000d0*m1**13 - 
     -     208618354980000d0*m1**14 + 47008669322160d0*m1**15 - 
     -     9197348345640d0*m1**16 + 1558654271460d0*m1**17 - 
     -     227873431500d0*m1**18 + 28572365250d0*m1**19 - 
     -     3047718960d0*m1**20 + 273513240d0*m1**21 -
     -     20343960d0*m1**22 + 
     -     1228500d0*m1**23 - 58500d0*m1**24 + 2106d0*m1**25 -  
     -     54d0*m1**26 + m1**27)*sqrtm1)*xxx**27)/
     -     (2.2487761296d12*(-4 + m1)**28*m1**28)

      Integral3exp = Integral3exp +
     -     ((-29*m1*(42365007009078721871904000d0 - 
     -     305477376297281268770289600d0*m1 + 
     -     1063107946111740927783184800d0*m1**2 - 
     -     2377817108522448126812197920d0*m1**3 + 
     -     3839984739714428889622518480d0*m1**4 - 
     -     4768766065344603373060289280d0*m1**5 + 
     -     4736196784857001979791678080d0*m1**6 - 
     -     3862489706189245601921566080d0*m1**7 + 
     -     2635341793903407768148314240d0*m1**8 - 
     -     1524974836243776001797634320d0*m1**9 + 
     -     756021196390802972882738520d0*m1**10 - 
     -     323523465000620189705253720d0*m1**11 + 
     -     120157540118012601455250780d0*m1**12 - 
     -     38879668854381375914073344d0*m1**13 + 
     -     10986405825357224066742656d0*m1**14 - 
     -     2714113668850816049727616d0*m1**15 + 
     -     586120410042261211056576d0*m1**16 - 
     -     110495861464483813219616d0*m1**17 + 
     -     18136530161887217954224d0*m1**18 - 
     -     2581241764666180427248d0*m1**19 + 
     -     316698065716321768728d0*m1**20 -
     -     33232844691098711808d0*m1**21 + 
     -     2951078471426142848d0*m1**22 -
     -     218614894672401920d0*m1**23 + 
     -     13249578898073776d0*m1**24 -
     -     639321957435636d0*m1**25 + 
     -     23614400160446d0*m1**26 -
     -     630809177806d0*m1**27 + 
     -     10876020307d0*m1**28) + 
     -     160626866400d0*arc*(7648690600760440d0 -
     -     54514303918147136d0*m1 + 
     -     187457205454383312d0*m1**2 -
     -     414121146690075552d0*m1**3 + 
     -     660269685411472500d0*m1**4 -
     -     809181571908528000d0*m1**5 + 
     -     792698243591872800d0*m1**6 -
     -     637318853651937600d0*m1**7 + 
     -     428441485458086100d0*m1**8 -
     -     244126202540220000d0*m1**9 + 
     -     119093998806783000d0*m1**10 -
     -     50112280017399600d0*m1**11 + 
     -     18285920359884450d0*m1**12 -
     -     5807935002643200d0*m1**13 + 
     -     1609341595560000d0*m1**14 -
     -     389420929296000d0*m1**15 + 
     -     82265171313780d0*m1**16 - 15148573745760d0*m1**17 + 
     -     2424573311160d0*m1**18 - 335813478000d0*m1**19 + 
     -     40001311350d0*m1**20 - 4063625280d0*m1**21 +
     -     348107760d0*m1**22 - 
     -     24766560d0*m1**23 + 1433250d0*m1**24 - 65520d0*m1**25 + 
     -     2268d0*m1**26 - 56d0*m1**27 + m1**28)*sqrtm1)*xxx**28)/
     -     (2.3290895628d12*(-4 + m1)**29*m1**29)

      Integral3exp = Integral3exp +
     -     ((m1*(-140058713172014254508514624000d0 + 
     -     1044911715375422135609576208000d0*m1 - 
     -     3767028382478447186053970016000d0*m1**2 + 
     -     8739420084717048773139080988000d0*m1**3 - 
     -     14659552699455641823815046517440d0*m1**4 + 
     -     18938105533042344553970368102800d0*m1**5 - 
     -     19597718841354770315784396134400d0*m1**6 + 
     -     16682265347234483284531197091200d0*m1**7 - 
     -     11903426727499974688947322252800d0*m1**8 + 
     -     7218701288680806033026155096320d0*m1**9 - 
     -     3759203235246174215874351403200d0*m1**10 + 
     -     1694108768594285382764555418600d0*m1**11 - 
     -     664491806196832237919235590160d0*m1**12 + 
     -     227790639503413044590920586460d0*m1**13 - 
     -     68435842713359451923749900288d0*m1**14 + 
     -     18047286152745263366918136960d0*m1**15 - 
     -     4179373784594801078464174080d0*m1**16 + 
     -     849363420972347230056922880d0*m1**17 - 
     -     151209111478853171602934400d0*m1**18 + 
     -     23509839155402338025186256d0*m1**19 - 
     -     3178245133567972609086880d0*m1**20 + 
     -     371320191839706483837240d0*m1**21 - 
     -     37187235088411408373760d0*m1**22 + 
     -     3158055366585304904320d0*m1**23 - 
     -     224151615130383917184d0*m1**24 +
     -     13038488819351160960d0*m1**25 - 
     -     604760056946748080d0*m1**26 +
     -     21502660684400850d0*m1**27 - 
     -     553622790683220d0*m1**28 + 9227046511387d0*m1**29) - 
     -     4658179125600d0*arc*
     -     (-30067266499541040d0 + 221812027422052760d0*m1 - 
     -     790457406813133472d0*m1**2 + 1812086319392372016d0*m1**3 - 
     -     3002378313503047752d0*m1**4 + 3829564175386540500d0*m1**5 - 
     -     3911044264224552000d0*m1**6 + 3284035580594901600d0*m1**7 - 
     -     2310280844488273800d0*m1**8 + 1380533675364944100d0*m1**9 - 
     -     707965987366638000d0*m1**10 + 313975087763337000d0*m1**11 - 
     -     121104676708715700d0*m1**12 + 40791668495126850d0*m1**13 - 
     -     12030722505475200d0*m1**14 + 3111393751416000d0*m1**15 - 
     -     705825434349000d0*m1**16 + 140334704005860d0*m1**17 - 
     -     24406035479280d0*m1**18 + 3700664527560d0*m1**19 - 
     -     486929543100d0*m1**20 + 55239906150d0*m1**21 - 
     -     5356596960d0*m1**22 + 438918480d0*m1**23 -
     -     29926260d0*m1**24+
     -     1662570d0*m1**25 - 73080*m1**26 + 2436*m1**27 - 58*m1**28 + 
     -     m1**29)*sqrtm1)*xxx**29)/
     -     (6.9872686884d13*(-4 + m1)**30*m1**30)

      Integral3exp = Integral3exp +
     -     ((-31*m1*(17770890488492131217209382400d0 - 
     -     137021597707173085190319235200d0*m1 + 
     -     511101880926456646829510988480d0*m1**2 - 
     -     1228326234453170697196495503360d0*m1**3 + 
     -     2137155417201437004170307949440d0*m1**4 - 
     -     2867746160687682486938445239520d0*m1**5 + 
     -     3087100988862051497952190621200d0*m1**6 - 
     -     2738089111292904579999823964160d0*m1**7 + 
     -     2039288021687049528878414104320d0*m1**8 - 
     -     1293347595157573397129286338880d0*m1**9 + 
     -     705855442639901171755889641440d0*m1**10 - 
     -     334140656405805727067111107200d0*m1**11 + 
     -     138023864911734671747371750176d0*m1**12 - 
     -     49969687371357933488896398872d0*m1**13 + 
     -     15904956935679081841184249908d0*m1**14 - 
     -     4459428425509776357606562304d0*m1**15 + 
     -     1102398349291515610318202880d0*m1**16 - 
     -     240251458036714891863936576d0*m1**17 + 
     -     46108271021852977702788192d0*m1**18 - 
     -     7775578167590804146440448d0*m1**19 + 
     -     1148350516363137048292544d0*m1**20 - 
     -     147830692064656761418000d0*m1**21 + 
     -     16483841438209710954680d0*m1**22 - 
     -     1578802304240520213760d0*m1**23 + 
     -     128466784634027152640d0*m1**24 -
     -     8751733750785368160d0*m1**25 + 
     -     489375112297551120d0*m1**26 -
     -     21851621159857248d0*m1**27 + 
     -     748939402168936d0*m1**28 -
     -     18609365660294d0*m1**29 + 
     -     300151059037d0*m1**30) + 
     -     4658179125600d0*arc*
     -     (118264581564861424d0 -
     -     902017994986231200d0*m1 + 
     -     3327180411330791400d0*m1**2 -
     -     7904574068131334720d0*m1**3 + 
     -     13590647395442790120d0*m1**4 -
     -     18014269881018286512d0*m1**5 + 
     -     19147820876932702500d0*m1**6 -
     -     16761618275248080000d0*m1**7 + 
     -     12315133427230881000d0*m1**8 -
     -     7700936148294246000d0*m1**9 + 
     -     4141601026094832300d0*m1**10 -
     -     1930816329181740000d0*m1**11 + 
     -     784937719408342500d0*m1**12 -
     -     279472330866267000d0*m1**13 + 
     -     87410718203843250d0*m1**14 -
     -     24061445010950400d0*m1**15 + 
     -     5833863283905000d0*m1**16 - 1245574295910000d0*m1**17 + 
     -     233891173343100d0*m1**18 - 38535845493600d0*m1**19 + 
     -     5550996791340d0*m1**20 - 695613633000d0*m1**21 + 
     -     75327144750d0*m1**22 - 6986865600d0*m1**23 +
     -     548648100d0*m1**24 - 
     -     35911512d0*m1**25 + 1918350d0*m1**26 - 81200*m1**27 + 
     -     2610*m1**28 - 60*m1**29 + m1**30)*sqrtm1)*xxx**30)/
     -     (7.22017764468d13*(-4 + m1)**31*m1**31)
#endif
      Integral3exp = conjg(Integral3exp)
      end

c-}}}

c-{{{ complex dilogarithm (from HIGLU)

      COMPLEX*16 FUNCTION CLI2(X)
C--COMPLEX DILOGARITHM (SPENCE-FUNCTION)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMPLEX*16 X,Y,SUSHI_CLI2
      COMMON/ZETACONST/ZETA2,ZETA3
      CLI2 = 0.D0
      ZERO=1.D-40
      XR=DREAL(X)
      XI=DIMAG(X)
      R2=XR*XR+XI*XI
      IF(R2.LE.ZERO)THEN
        CLI2=X
        RETURN
      ENDIF
      RR=XR/R2
      IF(R2.EQ.1.D0.AND.XI.EQ.0.D0)THEN
        IF(XR.EQ.1.D0)THEN
          CLI2=DCMPLX(ZETA2)
        ELSE
          CLI2=-DCMPLX(ZETA2/2.D0)
        ENDIF
        RETURN
      ELSEIF(R2.GT.1.D0.AND.RR.GT.0.5D0)THEN
        Y=(X-1.D0)/X
       CLI2=SUSHI_CLI2(Y)+ZETA2-CDLOG(X)*CDLOG(1.D0-X)+0.5D0*CDLOG(X)**2
        RETURN
      ELSEIF(R2.GT.1.D0.AND.RR.LE.0.5D0)THEN
        Y=1.D0/X
        CLI2=-SUSHI_CLI2(Y)-ZETA2-0.5D0*CDLOG(-X)**2
        RETURN
      ELSEIF(R2.LE.1.D0.AND.XR.GT.0.5D0)THEN
        Y=1.D0-X
        CLI2=-SUSHI_CLI2(Y)+ZETA2-CDLOG(X)*CDLOG(1.D0-X)
       RETURN
      ELSEIF(R2.LE.1.D0.AND.XR.LE.0.5D0)THEN
        Y=X
        CLI2=SUSHI_CLI2(Y)
        RETURN
      ENDIF
      END

      COMPLEX*16 FUNCTION SUSHI_CLI2(X)
C--TAYLOR-EXPANSION FOR COMPLEX DILOGARITHM (SPENCE-FUNCTION)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      COMPLEX*16 X,Z
      COMMON/BERNOULLI/B2(18),B12(18),B3(18)
      COMMON/POLY/NBER
      N=NBER-1
      Z=-CDLOG(1.D0-X)
      SUSHI_CLI2=B2(NBER)
      DO 111 I=N,1,-1
        SUSHI_CLI2=Z*SUSHI_CLI2+B2(I)
111   CONTINUE
      SUSHI_CLI2=Z**2*SUSHI_CLI2+Z
      RETURN
      END

      SUBROUTINE SUSHI_BERNINI(N)
C--INITIALIZATION OF COEFFICIENTS FOR POLYLOGARITHMS
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION B(18),PB(19)
      COMMON/BERNOULLI/B2(18),B12(18),B3(18)
      COMMON/ZETACONST/ZETA2,ZETA3
      COMMON/POLY/NBER
 
      NBER=N
      PI=4.D0*DATAN(1.D0)
 
      B(1)=-1.D0/2.D0
      B(2)=1.D0/6.D0
      B(3)=0.D0
      B(4)=-1.D0/30.D0
      B(5)=0.D0
      B(6)=1.D0/42.D0
      B(7)=0.D0
      B(8)=-1.D0/30.D0
      B(9)=0.D0
      B(10)=5.D0/66.D0
      B(11)=0.D0
      B(12)=-691.D0/2730.D0
      B(13)=0.D0
      B(14)=7.D0/6.D0
      B(15)=0.D0
      B(16)=-3617.D0/510.D0
      B(17)=0.D0
      B(18)=43867.D0/798.D0
      ZETA2=PI**2/6.D0
      ZETA3=1.202056903159594D0
 
      DO 995 I=1,18
        B2(I)=B(I)/SUSHI_FACULT(I+1)
        B12(I)=DFLOAT(I+1)/SUSHI_FACULT(I+2)*B(I)/2.D0
        PB(I+1)=B(I)
        B3(I)=0.D0
995   CONTINUE
      PB(1)=1.D0
      DO 996 I=1,18
      DO 996 J=0,I
       B3(I)=B3(I)+PB(J+1)*PB(I-J+1)/SUSHI_FACULT(I-J)/SUSHI_FACULT(J+1)
     .                                            /DFLOAT(I+1)
996   CONTINUE
 
      RETURN
      END
 
      DOUBLE PRECISION FUNCTION SUSHI_FACULT(N)
C--DOUBLE PRECISION VERSION OF FACULTY
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      SUSHI_FACULT=1.D0
      IF(N.EQ.0)RETURN
      DO 999 I=1,N
        SUSHI_FACULT=SUSHI_FACULT*DFLOAT(I)
999   CONTINUE
      RETURN
      END

c-}}}

C-{{{ real dilogarithm (from HqT)

        FUNCTION dli2(x)
        implicit none
*      !! Dilogarithm for arguments x < = 1.0
        real*8 X,Y,T,S,A,PI3,PI6,ZERO,ONE,HALF,MALF,MONE,MTWO
        real*8 C(0:18),H,ALFA,B0,B1,B2,LI2OLD
        real*8 dli2
        integer  i

        DATA ZERO /0.0d0/, ONE /1.0d0/
        DATA HALF /0.5d0/, MALF /-0.5d0/
        DATA MONE /-1.0d0/, MTWO /-2.0d0/
        DATA PI3 /3.289868133696453d0/, PI6 /1.644934066848226d0/

        DATA C( 0) / 0.4299669356081370d0/                              
        DATA C( 1) / 0.4097598753307711d0/                              
        DATA C( 2) /-0.0185884366501460d0/                              
        DATA C( 3) / 0.0014575108406227d0/                              
        DATA C( 4) /-0.0001430418444234d0/                              
        DATA C( 5) / 0.0000158841554188d0/                              
        DATA C( 6) /-0.0000019078495939d0/                              
        DATA C( 7) / 0.0000002419518085d0/                              
        DATA C( 8) /-0.0000000319334127d0/                              
        DATA C( 9) / 0.0000000043454506d0/                              
        DATA C(10) /-0.0000000006057848d0/                              
        DATA C(11) / 0.0000000000861210d0/                              
        DATA C(12) /-0.0000000000124433d0/                              
        DATA C(13) / 0.0000000000018226d0/                              
        DATA C(14) /-0.0000000000002701d0/                              
        DATA C(15) / 0.0000000000000404d0/                              
        DATA C(16) /-0.0000000000000061d0/                              
        DATA C(17) / 0.0000000000000009d0/                              
        DATA C(18) /-0.0000000000000001d0/                              
                                                                           
        if(x .gt. 1.00000000001d0) then                                    
          write(6,*)'problems in LI2'
          write(6,*)'x=',x 
          stop                                               
        elseif(x .gt. 1.0d0) then                                          
          x = 1.d0                                                      
        endif                                                              
        IF(X .EQ. ONE) THEN                                                
         LI2OLD=PI6
         dli2=LI2OLD                                                       
         RETURN                                                            
        ELSE IF(X .EQ. MONE) THEN                                          
         LI2OLD=MALF*PI6
         dli2=LI2OLD                                                  
         RETURN                                                            
        END IF                                                             
        T=-X                                                               
        IF(T .LE. MTWO) THEN                                               
         Y=MONE/(ONE+T)                                                    
         S=ONE                                                             
         A=-PI3+HALF*(LOG(-T)**2-LOG(ONE+ONE/T)**2)                        
        ELSE IF(T .LT. MONE) THEN                                          
         Y=MONE-T                                                          
         S=MONE                                                            
         A=LOG(-T)                                                         
         A=-PI6+A*(A+LOG(ONE+ONE/T))                                       
        ELSE IF(T .LE. MALF) THEN                                          
         Y=(MONE-T)/T                                                      
         S=ONE                                                             
         A=LOG(-T)                                                         
         A=-PI6+A*(MALF*A+LOG(ONE+T))                                      
        ELSE IF(T .LT. ZERO) THEN                                          
         Y=-T/(ONE+T)                                                      
         S=MONE                                                            
         A=HALF*LOG(ONE+T)**2                                              
        ELSE IF(T .LE. ONE) THEN                                           
         Y=T                                                               
         S=ONE                                                             
         A=ZERO                                                            
        ELSE                                                               
         Y=ONE/T                                                           
         S=MONE                                                            
         A=PI6+HALF*LOG(T)**2                                              
        END IF                                                             
                                                                           
        H=Y+Y-ONE                                                          
        ALFA=H+H                                                           
        B1=ZERO                                                            
        B2=ZERO                                                            
        DO  I = 18,0,-1                                                    
          B0=C(I)+ALFA*B1-B2                                               
          B2=B1                                                            
          B1=B0                                                            
        ENDDO                                                              
        LI2OLD=-(S*(B0-H*B2)+A) 
         dli2=LI2OLD
        end     

C-}}}
C-{{{ real dilogarithm (not used)

c$$$C     ALGORITHM 490 COLLECTED ALGORITHMS FROM ACM.
c$$$C     ALGORITHM APPEARED IN COMM. ACM, VOL. 18, NO. 4N,
c$$$C     P. 200.
c$$$      DOUBLE PRECISION FUNCTION DILOG2(X)                                DIL   10
c$$$C REAL PART OF THE DILOGARITHM FUNCTION FOR A REAL
c$$$C ARGUMENT. REF. NO. 1=L. LEWIN, *DILOGARITHMS +
c$$$C ASSOCIATED FUNCTIONS*
c$$$C                      (MAC-DONALD, LONDON, 1958).
c$$$C NUMERICAL CONSTANTS USED ARE C(N)=(N(N+1)(N+2))**2
c$$$C FOR N=1 TO 30, (PI**2)/3=3.289868...,
c$$$C (PI**2)/6=1.644394..., AND ZERO OF DILOG ON THE
c$$$C POSITIVE REAL AXIS, X0=12.59517...
c$$$      DOUBLE PRECISION A, B, BY, C, C1, C2, C3, C4,
c$$$     * DX, DY, TEST, W, X, X0, Y, Z
c$$$      DIMENSION C(30)
c$$$      DATA C(1), C(2), C(3), C(4), C(5), C(6), C(7),
c$$$     * C(8), C(9), C(10), C(11), C(12), C(13),
c$$$     * C(14), C(15), C(16), C(17), C(18), C(19),
c$$$     * C(20), C(21), C(22), C(23), C(24), C(25),
c$$$     * C(26), C(27), C(28), C(29), C(30)
c$$$     * /36.D0,576.D0,36.D2,144.D2,441.D2,112896.D0,
c$$$     * 254016.D0,5184.D2,9801.D2,17424.D2,2944656.D0,
c$$$     * 4769856.D0,74529.D2,112896.D2,166464.D2,
c$$$     * 23970816.D0,33802596.D0,467856.D2,636804.D2,
c$$$     * 853776.D2,112911876.D0,147476736.D0,19044.D4,
c$$$     * 24336.D4,3080025.D2,386358336.D0,480661776.D0,
c$$$     * 5934096.D2,7273809.D2,8856576.D2/
c$$$      IF (X.GT.12.6D0) GO TO 10
c$$$      IF (X.GE.12.59D0) GO TO 100
c$$$      IF (X.GE.2.D0) GO TO 10
c$$$      IF (X.GT.1.D0) GO TO 20
c$$$      IF (X.EQ.1.D0) GO TO 30
c$$$      IF (X.GT..5D0) GO TO 40
c$$$      IF (X.GT.1.D-2) GO TO 50
c$$$      IF (X.LT.-1.D0) GO TO 60
c$$$      IF (X.LT.-1.D-2) GO TO 70
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.244, EQ(1).
c$$$      DILOG2 = X*(1.D0+X*(.25D0+X*(1.D0/9.D0+X*
c$$$     * (625.D-4+X*(4.D-2+X*(1.D0/36.D0+X*(1.D0/
c$$$     * 49.D0+X/64.D0)))))))
c$$$      RETURN
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.244, EQ(6),
c$$$C AND DESCRIPTION OF THIS ALGORITHM, EQ(4).
c$$$   10 Y = 1.D0/X
c$$$      BY = -1.D0 - Y*(4.D0+Y)
c$$$      DILOG2 = 3.28986813369645287D0 -
c$$$     * .5D0*DLOG(X)**2 + (Y*(4.D0+5.75D0*Y)+3.D0*
c$$$     * (1.D0+Y)*(1.D0-Y)*DLOG(1.D0-Y))/BY
c$$$      IF (DILOG2+4.D0*Y.EQ.DILOG2) RETURN
c$$$      GO TO 80
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.244, EQ(7) WITH
c$$$C X=1/X + EQ(6), AND DESCRIPTION OF THIS ALGORITHM,
c$$$C EQ(4).
c$$$   20 Y = 1.D0 - 1.D0/X
c$$$      DX = DLOG(X)
c$$$      BY = 1.D0 + Y*(4.D0+Y)
c$$$      DILOG2 = 1.64493406684822643D0 +
c$$$     * DX*(.5D0*DX-DLOG(X-1.D0)) +
c$$$     * (Y*(4.D0+5.75D0*Y)-3.D0*(1.D0+Y)*DX/X)/BY
c$$$      GO TO 80
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.244, EQ(2).
c$$$   30 DILOG2 = 1.64493406684822643D0
c$$$      RETURN
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.244, EQ(7),
c$$$C AND DESCRIPTION OF THIS ALGORITHM, EQ(4).
c$$$   40 Y = 1.D0 - X
c$$$      DX = DLOG(X)
c$$$      BY = -1.D0 - Y*(4.D0+Y)
c$$$      DILOG2 = 1.64493406684822643D0 - DX*DLOG(Y) +
c$$$     * (Y*(4.D0+5.75D0*Y)+3.D0*(1.D0+Y)*DX*X)/BY
c$$$      GO TO 80
c$$$C DILOG COMPUTED FROM DESCRIPTION OF THIS ALGORITHM,
c$$$C EQ(4)
c$$$   50 Y = X
c$$$      BY = 1.D0 + Y*(4.D0+Y)
c$$$      DILOG2 = (Y*(4.D0+5.75D0*Y)+3.D0*(1.D0+Y)*
c$$$     * (1.D0-Y)*DLOG(1.D0-Y))/BY
c$$$      GO TO 80
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.245, EQ(12) WITH
c$$$C X=-X, AND DESCRIPTION OF THIS ALGORITHM, EQ(4).
c$$$   60 Y = 1.D0/(1.D0-X)
c$$$      DX = DLOG(-X)
c$$$      DY = DLOG(Y)
c$$$      BY = 1.D0 + Y*(4.D0+Y)
c$$$      DILOG2 = -1.64493406684822643D0 +
c$$$     * .5D0*DY*(DY+2.D0*DX) + (Y*(4.D0+5.75D0*Y)
c$$$     * +3.D0*(1.D0+Y)*(1.D0-Y)*(DX+DY))/BY
c$$$      IF (DILOG2+4.D0*Y.EQ.DILOG2) RETURN
c$$$      GO TO 80
c$$$C DILOG COMPUTED FROM REF. NO. 1, P.244, EQ(8),
c$$$C AND DESCRIPTION OF THIS ALGORITHM, EQ(4).
c$$$   70 Y = X/(X-1.D0)
c$$$      DX = DLOG(1.D0-X)
c$$$      BY = -1.D0 - Y*(4.D0+Y)
c$$$      DILOG2 = (Y*(4.D0+5.75D0*Y)-3.D0*(1.D0+Y)*
c$$$     * (1.D0-Y)*DX)/BY - .5D0*DX*DX
c$$$   80 B = 4.D0*Y*Y/BY
c$$$      DO 90 N=1,30
c$$$        B = B*Y
c$$$        A = B/C(N)
c$$$        TEST = DILOG2
c$$$        DILOG2 = DILOG2 + A
c$$$        IF (DILOG2.EQ.TEST) RETURN
c$$$   90 CONTINUE
c$$$      RETURN
c$$$C DILOG COMPUTED FROM TAYLOR SERIES ABOUT ZERO OF
c$$$C DILOG, X0.
c$$$  100 X0 = 12.5951703698450184D0
c$$$      Y = X/X0 - 1.D0
c$$$      Z = 1.D0/11.5951703698450184D0
c$$$      W = Y*Z
c$$$      C1 = (3.D0*X0-2.D0)/6.D0
c$$$      C2 = ((11.D0*X0-15.D0)*X0+6.D0)/24.D0
c$$$      C3 = (((5.D1*X0-104.D0)*X0+84.D0)*X0-24.D0)/
c$$$     * 12.D1
c$$$      C4 = ((((274.D0*X0-77.D1)*X0+94.D1)*X0-54.D1)*
c$$$     * X0+12.D1)/72.D1
c$$$      DILOG2 = Y*(1.D0-Y*(.5D0-Y*(1.D0/3.D0-Y*
c$$$     * (.25D0-Y*(.2D0-Y/6.D0)))))*DLOG(Z) -
c$$$     * W*X0*Y*(.5D0-W*(C1-W*(C2-W*(C3-W*C4))))
c$$$      RETURN
c$$$      END

C-}}}
